# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/beejees/candidate/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Beejees\\Candidate\\": "packages/beejees/candidate/src",
            "Beejees\\Candidate\\Seeders\\": "packages/beejees/candidate/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Beejees\Candidate\Providers\CandidateServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Candidate'  => Beejees\Candidate\Facades\Candidate::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Beejees\\Candidate\\Seeders\\CandidateTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Beejees\Candidate\Providers\CandidateServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Beejees\Candidate\Providers\CandidateServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Beejees\Candidate\Providers\CandidateServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/candidate/{modulename}

**User**

    http://path-to-route-folder/user/candidate/{modulename}

**Public**

    http://path-to-route-folder/candidates


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/candidate/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/candidate/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/candidate/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/candidate/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/candidate/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/candidate/{modulename}/{slug}
    METHOD: GET