<?php

namespace Beejees\Candidate\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Beejees\Candidate\Models\Candidate;

class CandidatePolicy
{

    /**
     * Determine if the given user can view the candidate.
     *
     * @param UserPolicyInterface $authUser
     * @param Candidate $candidate
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Candidate $candidate)
    {
        if ($authUser->canDo('candidate.candidate.view') && $authUser->isAdmin()) {
            return true;
        }

        return $candidate->user_id == user_id() && $candidate->user_type == user_type();
    }

    /**
     * Determine if the given user can create a candidate.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('candidate.candidate.create');
    }

    /**
     * Determine if the given user can update the given candidate.
     *
     * @param UserPolicyInterface $authUser
     * @param Candidate $candidate
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Candidate $candidate)
    {
        if ($authUser->canDo('candidate.candidate.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $candidate->user_id == user_id() && $candidate->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given candidate.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Candidate $candidate)
    {
        return $candidate->user_id == user_id() && $candidate->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given candidate.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Candidate $candidate)
    {
        if ($authUser->canDo('candidate.candidate.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given candidate.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Candidate $candidate)
    {
        if ($authUser->canDo('candidate.candidate.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
