<?php

namespace Beejees\Candidate\Providers;

use Illuminate\Support\ServiceProvider;
use Beejees\Candidate\Candidates;

class CandidateServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'candidate');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'candidate');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Beejees\Candidate\Providers\AuthServiceProvider::class);
        $this->app->register(\Beejees\Candidate\Providers\RouteServiceProvider::class);
        // $this->app->register(\Beejees\Candidate\Providers\EventServiceProvider::class);
        // $this->app->register(\Beejees\Candidate\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('beejees.candidate', function($app)
        {
            return $this->app->make(Candidates::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind Candidate to repository
        $this->app->bind(
            'Beejees\Candidate\Interfaces\CandidateRepositoryInterface',
            \Beejees\Candidate\Repositories\Eloquent\CandidateRepository::class
        );
    }


    /**
     * Merges user's and candidate's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'beejees.candidate'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Beejees\Candidate\Commands\Candidate::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['beejees.candidate'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('beejees/candidate.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/candidate')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/candidate')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
